#!/usr/bin/python

'''
build_native.py

This script will copy resources to assets and build native code with NDK.
'''
import sys
import os, os.path
import shutil
from optparse import OptionParser

def get_num_of_cpu():
    return 4
    ''' The build process can be accelerated by running multiple concurrent job processes using the -j-option.
    '''
    try:
        platform = sys.platform
        if platform == 'win32':
            if 'NUMBER_OF_PROCESSORS' in os.environ:
                return int(os.environ['NUMBER_OF_PROCESSORS'])
            else:
                return 4
        else:
            from numpy.distutils import cpuinfo
            return cpuinfo.cpu._getNCPUs()
    except Exception:
        print "Can't know cpuinfo, use default 2 cpu"
        return 4

def check_environment_variables():
    ''' Checking the environment NDK_ROOT, which will be used for building
    '''

    try:
        NDK_ROOT = os.environ['NDK_ROOT']
    except Exception:
        print "NDK_ROOT not defined. Please define NDK_ROOT in your environment"
        sys.exit(1)

    return NDK_ROOT

def do_build(ndk_root, app_android_root, ndk_build_param,build_mode):

    ndk_path = os.path.join(ndk_root, "ndk-build")

    num_of_cpu = get_num_of_cpu()
    if ndk_build_param == None:
        command = '%s -j%d -C %s NDK_DEBUG=%d' % (ndk_path, num_of_cpu, app_android_root, build_mode=='debug')
    else:
        command = '%s -j%d -C %s NDK_DEBUG=%d %s' % (ndk_path, num_of_cpu, app_android_root, build_mode=='debug', ndk_build_param)
    # print command
    if os.system(command) != 0:
        raise Exception("Build dynamic library for project [ " + app_android_root + " ] fails!")

def build(targets,ndk_build_param,build_mode):

    ndk_root = check_environment_variables()

    project_root = os.path.dirname(os.path.realpath(__file__))

    if build_mode is None:
        build_mode = 'release'
    elif build_mode != 'debug':
        build_mode = 'release'

    do_build(ndk_root, project_root,ndk_build_param,build_mode)

# -------------- main --------------
if __name__ == '__main__':

    parser = OptionParser()
    parser.add_option("-n", "--ndk", dest="ndk_build_param",
    help='Parameter for ndk-build')
    parser.add_option("-b", "--build", dest="build_mode",
    help='The build mode for NDK project, debug or release')
    (opts, args) = parser.parse_args()

    try:
        build(args, opts.ndk_build_param,opts.build_mode)
    except Exception as e:
        print e
        sys.exit(1)
